import click
import os

from . import init


@click.command()
@click.argument('filename')
@click.option('--start', default=1, envvar='PAGE_START')
@click.option('--end', default=None, envvar='PAGE_END')
@click.option('--step', default=1, envvar='PAGE_STEP')
@click.option('--random/--no-random', default=True, envvar='PAGE_RANDOM')
@click.option('--host', default='localhost', envvar='HOST')
@click.option('--port', default=5000, envvar='PORT')
def pdf_shuffle(filename, start, end, step, random, host, port):
    init(filename, start, end, step, random, host, port)


def pdf_quiz():
    os.environ.update({
        'PAGE_START': '2',
        'PAGE_STEP': '2'
    })
    pdf_shuffle()



import webbrowser
from threading import Thread
from time import sleep
import os


def open_browser_tab(url):
    def _open_tab():
        sleep(1)
        webbrowser.open_new_tab(url)

    thread = Thread(target=_open_tab)
    thread.daemon = True
    thread.start()


def list_pdf(path):
    for (dirpath, dirnames, filenames) in os.walk(path):
        for filename in filenames:
            if os.path.splitext(filename)[1].lower() == '.pdf' and filename[0] != '.':
                yield os.path.join(dirpath, filename)



from flask import render_template, send_file, request
import os
import json
from urllib.parse import unquote
import random

from . import app
from .util import list_pdf


@app.route('/')
def index():
    return render_template('index.html', config={
        'filename': os.getenv('FILENAME'),
        'start': json.loads(os.getenv('PAGE_START', '1')),
        'end': json.loads(os.getenv('PAGE_END', 'null')),
        'step': json.loads(os.getenv('PAGE_STEP', '1')),
        'random': json.loads(os.getenv('PAGE_RANDOM', '1'))
    })


@app.route('/file')
def send_pdf():
    filename = os.path.abspath(unquote(request.args.get('filename')))
    cache_timeout = None
    if os.path.isdir(filename):
        filename = random.choice(tuple(list_pdf(filename)))
        print(filename)
        cache_timeout = 0

    return send_file(filename, cache_timeout=cache_timeout)



# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['pdf_shuffle']

package_data = \
{'': ['*'], 'pdf_shuffle': ['static/*', 'templates/*']}

install_requires = \
['click>=6.7,<7.0', 'flask>=1.0,<2.0']

entry_points = \
{'console_scripts': ['pdf-quiz = pdf_shuffle.__main__:pdf_quiz',
                     'pdf-shuffle = pdf_shuffle.__main__:pdf_shuffle']}

setup_kwargs = {
    'name': 'pdf-shuffle',
    'version': '0.2.0',
    'description': 'A PDF page/image randomizer, or flashcard quiz from a PDF.',
    'long_description': "# pdf-shuffle\n\n[![PyPI version shields.io](https://img.shields.io/pypi/v/pdf_shuffle.svg)](https://pypi.python.org/pypi/pdf_shuffle/)\n[![PyPI license](https://img.shields.io/pypi/l/pdf_shuffle.svg)](https://pypi.python.org/pypi/pdf_shuffle/)\n\nA PDF page/image randomizer, or flashcard quiz from a PDF.\n\n## Installation\n\n```\n$ pip install pdf-shuffle\n```\n\n## Usage\n\npdf-shuffle comes with 2 CLI applications:\n\n```\n$ pdf-shuffle --help\nUsage: pdf-shuffle [OPTIONS] FILENAME\n\nOptions:\n  --start INTEGER\n  --end TEXT\n  --step INTEGER\n  --random / --no-random\n  --host TEXT\n  --port INTEGER\n  --help                  Show this message and exit.\n$ pdf-shuffle test.pdf\n```\n\nAnd,\n\n```\n$ pdf-quiz --help\nUsage: pdf-quiz [OPTIONS] FILENAME\n\nOptions:\n  --start INTEGER\n  --end TEXT\n  --step INTEGER\n  --random / --no-random\n  --host TEXT\n  --port INTEGER\n  --help                  Show this message and exit.\n$ pdf-quiz quiz.pdf\n```\n\nOf course, you can invoke the app from a Python script as well.\n\n```python\nfrom pdf_shuffle import init\ninit('test.pdf')\n```\n\nOr,\n\n```python\nfrom pdf_shuffle import init_quiz\ninit_quiz('quiz.pdf')\n```\n\nYou can also random files in a folder:\n\n```python\nfrom pdf_shuffle import init\ninit('test/')\n```\n\n## Advanced usage\n\nBy default, `quiz.pdf` means, excluding the first slide, every first and second slides are front of the card and back of the card, respectively. You can change that, with:\n\n```python\nimport os, json\nos.environ['PAGE_RANDOM'] = json.dumps([2, 3, 5, 9, 12])\n```\n\n## Spaced-repetition system (SRS)\n\nIf you are looking into extending the app with SRS, you might try, [srs-sqlite](https://github.com/patarapolw/srs-sqlite), which I currently use.\n",
    'author': 'patarapolw',
    'author_email': 'patarapolw@gmail.com',
    'url': 'https://github.com/patarapolw/pdf-shuffle',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
}


setup(**setup_kwargs)



from flask import Flask
import os
import json

app = Flask(__name__)

from .views import index, send_pdf
from .util import open_browser_tab


def init(filename, start=1, end=None, step=1, random=True, host='localhost', port=5000):
    """

    :param filename:
    :param start:
    :param end:
    :param step:
    :param bool|list|tuple random:
    :param host:
    :param port:
    :return:
    """
    os.environ.update({
        'FILENAME': filename,
        'PAGE_START': str(start),
        'PAGE_END': json.dumps(end),
        'PAGE_STEP': str(step),
        'PAGE_RANDOM': json.dumps(random),
        'HOST': host,
        'PORT': str(port)
    })

    open_browser_tab('http://{}:{}/'.format(os.getenv('HOST'), os.getenv('PORT')))
    app.run(host=os.getenv('HOST'), port=os.getenv('PORT'))


def init_quiz(filename, start=2, end=None, step=2, random=True, host='localhost', port=5000):
    """

    :param filename:
    :param start:
    :param end:
    :param step:
    :param bool|list|tuple random:
    :param host:
    :param port:
    :return:
    """
    init(filename, start, end, step, random, host, port)
